==> mediawiki-1.37.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/SyntaxHighlight_GeSHi/includes/ResourceLoaderPygmentsModule.php <==
<?php
/**
 * Copyright (C) 2021 Kunal Mehta <legoktm@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 */

namespace MediaWiki\SyntaxHighlight;

use ResourceLoaderContext;
use ResourceLoaderFileModule;

/**
 * At runtime switch between bundled CSS or dynamically generated
 */
class ResourceLoaderPygmentsModule extends ResourceLoaderFileModule {

	/** @var bool */
	private $useBundled;

	/** @inheritDoc */
	public function __construct(
		array $options = [],
		$localBasePath = null,
		$remoteBasePath = null
	) {
		$this->useBundled = Pygmentize::useBundled();
		if ( $this->useBundled ) {
			// Generated styles before our overrides
			array_unshift( $options['styles'], 'pygments.generated.css' );
		}
		parent::__construct( $options, $localBasePath, $remoteBasePath );
	}

	/**
	 * We sometimes have generated styles
	 *
	 * @return bool
	 */
	public function supportsURLLoading() {
		return false;
	}

	/** @inheritDoc */
	public function getStyles( ResourceLoaderContext $context ) {
		$styles = parent::getStyles( $context );
		if ( !$this->useBundled ) {
			// Generated styles before our overrides
			$styles['all'] = Pygmentize::getGeneratedCSS() . ( $styles['all'] ?? '' );
		}

		return $styles;
	}

	/** @inheritDoc */
	public function getDefinitionSummary( ResourceLoaderContext $context ) {
		$summary = parent::getDefinitionSummary( $context );
		if ( !$this->useBundled ) {
			$summary[] = Pygmentize::getVersion();
		}
		return $summary;
	}

}

==> mediawiki-1.41.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/extensions/SyntaxHighlight_GeSHi/includes/ResourceLoaderPygmentsModule.php <==
<?php
/**
 * Copyright (C) 2021 Kunal Mehta <legoktm@debian.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * http://www.gnu.org/copyleft/gpl.html
 */

namespace MediaWiki\SyntaxHighlight;

use MediaWiki\ResourceLoader as RL;

/**
 * At runtime switch between bundled CSS or dynamically generated
 */
class ResourceLoaderPygmentsModule extends RL\FileModule {

	/** @var bool */
	private $useBundled;

	/** @inheritDoc */
	public function __construct(
		array $options = [],
		$localBasePath = null,
		$remoteBasePath = null
	) {
		$this->useBundled = Pygmentize::useBundled();
		if ( $this->useBundled ) {
			// Generated styles before our overrides
			array_unshift( $options['styles'], 'pygments.generated.css' );
		}
		parent::__construct( $options, $localBasePath, $remoteBasePath );
	}

	/**
	 * We sometimes have generated styles
	 *
	 * @return bool
	 */
	public function supportsURLLoading() {
		return false;
	}

	/** @inheritDoc */
	public function getStyles( RL\Context $context ) {
		$styles = parent::getStyles( $context );
		if ( !$this->useBundled ) {
			// Generated styles before our overrides
			$styles['all'] = Pygmentize::getGeneratedCSS() . ( $styles['all'] ?? '' );
		}

		return $styles;
	}

	/** @inheritDoc */
	public function getDefinitionSummary( RL\Context $context ) {
		$summary = parent::getDefinitionSummary( $context );
		if ( !$this->useBundled ) {
			$summary[] = Pygmentize::getVersion();
		}
		return $summary;
	}

}
